@@ -26,8 +26,8 @@
 #   PYTHONPATH=/path/to/LLDB.framework/Resources/Python ./crashlog.py ~/Library/Logs/DiagnosticReports/a.crash
 #----------------------------------------------------------------------
 
+from __future__ import print_function
 import lldb
-import subprocess
 import optparse
 import os
 import plistlib
@@ -248,7 +248,6 @@ class Image:
         obj = cls(module.file.fullpath, module.uuid)
         obj.resolved_path = module.platform_file.fullpath
         obj.resolved = True
-        obj.arch = module.triple
         for section in module.sections:
             symb_section = Section.InitWithSBTargetAndSBSection(
                 target, section)
@@ -380,7 +379,7 @@ class Image:
                     return None
                 resolved_path = self.get_resolved_path()
                 self.module = target.AddModule(
-                    resolved_path, self.arch, uuid_str, self.symfile)
+                    resolved_path, str(self.arch), uuid_str, self.symfile)
             if not self.module:
                 return 'error: unable to get module for (%s) "%s"' % (
                     self.arch, self.get_resolved_path())
@@ -419,7 +418,6 @@ class Image:
         if self.locate_module_and_debug_symbols():
             resolved_path = self.get_resolved_path()
             path_spec = lldb.SBFileSpec(resolved_path)
-            #result.PutCString ('plist[%s] = %s' % (uuid, self.plist))
             error = lldb.SBError()
             target = lldb.debugger.CreateTarget(
                 resolved_path, self.arch, None, False, error)
@@ -575,7 +573,6 @@ def disassemble_instructions(
         mnemonic = inst.GetMnemonic(target)
         operands = inst.GetOperands(target)
         comment = inst.GetComment(target)
-        #data = inst.GetData (target)
         lines.append("%#16.16x: %8s %s" % (inst_pc, mnemonic, operands))
         if comment:
             line_len = len(lines[-1])
